"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var paycards_recognizer_common_1 = require("./paycards-recognizer.common");
var RecognizerViewController = (function (_super) {
    __extends(RecognizerViewController, _super);
    function RecognizerViewController() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this._callback = null;
        return _this;
    }
    RecognizerViewController.prototype.viewDidLoad = function () {
        _super.prototype.viewDidLoad.call(this);
        this.recognizer = PayCardsRecognizer.alloc().initWithDelegateResultModeContainerFrameColor(this, PayCardsRecognizerResultModeAsync, this.view, UIColor.greenColor);
    };
    RecognizerViewController.prototype.viewWillAppear = function (animated) {
        _super.prototype.viewWillAppear.call(this, animated);
        var backButton = UIBarButtonItem.alloc()
            .initWithTitleStyleTargetAction('Cancel', 0, this, 'onBackButtonClick');
        this.navigationItem.hidesBackButton = false;
        this.navigationItem.leftBarButtonItem = backButton;
        this.recognizer.startCamera();
    };
    RecognizerViewController.prototype.viewDidDisappear = function (animated) {
        _super.prototype.viewDidDisappear.call(this, animated);
        this.recognizer.stopCamera();
    };
    RecognizerViewController.prototype.payCardsRecognizerDidRecognize = function (recognizer, result) {
        if (result.isCompleted) {
            if (this._callback) {
                var card = paycards_recognizer_common_1.Card.fromIOSResult(result);
                this._callback(card);
            }
            getViewControllerToPresentFrom()
                .dismissViewControllerAnimatedCompletion(true, null);
        }
    };
    RecognizerViewController.prototype.onBackButtonClick = function () {
        getViewControllerToPresentFrom()
            .dismissViewControllerAnimatedCompletion(true, null);
    };
    RecognizerViewController.prototype.setCallback = function (callback) {
        this._callback = callback;
    };
    RecognizerViewController.ObjCProtocols = [PayCardsRecognizerPlatformDelegate];
    RecognizerViewController.ObjCExposedMethods = {
        onBackButtonClick: {
            returns: interop.types.void,
            params: [interop.types.id]
        }
    };
    return RecognizerViewController;
}(UIViewController));
function getViewControllerToPresentFrom() {
    var frame = require('tns-core-modules/ui/frame');
    var viewController;
    var topMostFrame = frame.topmost();
    if (topMostFrame) {
        viewController = topMostFrame.currentPage && topMostFrame.currentPage.ios;
        if (viewController) {
            while (viewController.parentViewController) {
                viewController = viewController.parentViewController;
            }
            while (viewController.presentedViewController) {
                viewController = viewController.presentedViewController;
            }
        }
    }
    if (!viewController) {
        viewController = UIApplication.sharedApplication.keyWindow.rootViewController;
    }
    return viewController;
}
var PaycardsRecognizer = (function () {
    function PaycardsRecognizer() {
    }
    PaycardsRecognizer.prototype.recognize = function () {
        var recognizerView = RecognizerViewController.new();
        var nav = UINavigationController.alloc().initWithRootViewController(recognizerView);
        nav.navigationBar.barTintColor = UIColor.blackColor;
        nav.navigationBar.tintColor = UIColor.whiteColor;
        nav.navigationBar.titleTextAttributes = NSDictionary.dictionaryWithObjectForKey(UIColor.whiteColor, NSForegroundColorAttributeName);
        nav.navigationBar.barStyle = 1;
        setTimeout(function () {
            getViewControllerToPresentFrom()
                .presentViewControllerAnimatedCompletion(nav, true, function () { });
        }, 0);
        return new Promise(function (resolve, reject) {
            try {
                recognizerView.setCallback(resolve);
            }
            catch (err) {
                reject(err);
            }
        });
    };
    return PaycardsRecognizer;
}());
exports.PaycardsRecognizer = PaycardsRecognizer;
//# sourceMappingURL=paycards-recognizer.ios.js.map